Package: DEGreport
Version: 1.48.0
Date: 2025-10-11
Type: Package
Title: Report of DEG analysis
Description: Creation of ready-to-share figures of differential expression
    analyses of count data. It integrates some of the code
    mentioned in DESeq2 and edgeR vignettes, and report a ranked
    list of genes according to the fold changes mean and
    variability for each selected gene.
biocViews: DifferentialExpression, Visualization, RNASeq,
        ReportWriting, GeneExpression, ImmunoOncology
URL: http://lpantano.github.io/DEGreport/
BugReports: https://github.com/lpantano/DEGreport/issues
Suggests: BiocStyle, AnnotationDbi, limma, pheatmap, rmarkdown,
        statmod, testthat
Depends: R (>= 4.0.0)
Imports: utils, methods, Biobase, BiocGenerics, broom, circlize,
        ComplexHeatmap, cowplot, ConsensusClusterPlus, cluster,
        dendextend, DESeq2, dplyr, edgeR, ggplot2, ggdendro, grid,
        ggrepel, grDevices, knitr, logging, magrittr, psych,
        RColorBrewer, reshape, rlang, scales, stats, stringr, stringi,
        S4Vectors, SummarizedExperiment, tidyr, tibble
Authors@R: c(person("Lorena", "Pantano", email = "lorena.pantano@gmail.com", 
  role = c("aut", "cre")),
  person("John", "Hutchinson",  role = c("ctb")),
  person("Victor", "Barrera",  role = c("ctb")),
  person("Mary", "Piper",  role = c("ctb")),
  person("Radhika", "Khetani",  role = c("ctb")),
  person("Kenneth", "Daily", role=c("ctb")),
  person("Thanneer", "Malai Perumal", role=c("ctb")),
  person("Rory", "Kirchner",  role=c("ctb")),
  person("Michael", "Steinbaugh",  role=c("ctb")),
  person("Ivo", "Zeller",  role=c("ctb")))
Maintainer: Lorena Pantano <lorena.pantano@gmail.com>
License: MIT + file LICENSE
VignetteBuilder: knitr
RoxygenNote: 7.3.1
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
git_url: https://git.bioconductor.org/packages/DEGreport
git_branch: RELEASE_3_23
git_last_commit: bc514a8
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:39:54 UTC; biocbuild
Author: Lorena Pantano [aut, cre],
  John Hutchinson [ctb],
  Victor Barrera [ctb],
  Mary Piper [ctb],
  Radhika Khetani [ctb],
  Kenneth Daily [ctb],
  Thanneer Malai Perumal [ctb],
  Rory Kirchner [ctb],
  Michael Steinbaugh [ctb],
  Ivo Zeller [ctb]
