# Generated by roxygen2: do not edit by hand

export(DEGSet)
export(as.DEGSet)
export(createReport)
export(deg)
export(degCheckFactors)
export(degColors)
export(degComps)
export(degCorCov)
export(degCorrect)
export(degCovariates)
export(degDefault)
export(degFilter)
export(degMA)
export(degMB)
export(degMDS)
export(degMV)
export(degMean)
export(degObj)
export(degPCA)
export(degPatterns)
export(degPlot)
export(degPlotCluster)
export(degPlotWide)
export(degQC)
export(degResults)
export(degSignature)
export(degSummary)
export(degVB)
export(degVar)
export(degVolcano)
export(geom_cor)
export(significants)
exportMethods(as.DEGSet)
exportMethods(deg)
exportMethods(degCorrect)
exportMethods(degDefault)
exportMethods(significants)
import(cluster)
import(edgeR)
import(ggplot2)
import(ggrepel)
import(logging)
import(utils)
importFrom("grDevices","colorRampPalette")
importFrom("grDevices","dev.off")
importFrom("grDevices","jpeg")
importFrom("grDevices","pdf")
importFrom("grDevices","rgb")
importFrom("methods","slotNames")
importFrom("stats","aov")
importFrom("stats","as.dendrogram")
importFrom("stats","as.dist")
importFrom("stats","as.hclust")
importFrom("stats","cmdscale")
importFrom("stats","cor")
importFrom("stats","cor.test")
importFrom("stats","cutree")
importFrom("stats","density")
importFrom("stats","dist")
importFrom("stats","hclust")
importFrom("stats","median")
importFrom("stats","median.default")
importFrom("stats","na.omit")
importFrom("stats","p.adjust")
importFrom("stats","prcomp")
importFrom("stats","quantile")
importFrom("stats","sd")
importFrom("stats","time")
importFrom("stats","var")
importFrom("stats","xtabs")
importFrom(Biobase,rowMax)
importFrom(Biobase,rowMin)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,HeatmapAnnotation)
importFrom(ConsensusClusterPlus,ConsensusClusterPlus)
importFrom(ConsensusClusterPlus,calcICL)
importFrom(DESeq2,lfcShrink)
importFrom(DESeq2,plotCounts)
importFrom(DESeq2,results)
importFrom(DESeq2,resultsNames)
importFrom(DESeq2,rlog)
importFrom(RColorBrewer,brewer.pal)
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,SimpleList)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(broom,tidy)
importFrom(circlize,colorRamp2)
importFrom(cowplot,draw_plot)
importFrom(cowplot,ggdraw)
importFrom(cowplot,plot_grid)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,select)
importFrom(dplyr,select_if)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggdendro,dendro_data)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,layer)
importFrom(grid,textGrob)
importFrom(knitr,kable)
importFrom(magrittr,set_colnames)
importFrom(magrittr,set_rownames)
importFrom(methods,new)
importFrom(methods,slot)
importFrom(psych,corr.test)
importFrom(reshape,melt)
importFrom(reshape,melt.data.frame)
importFrom(rlang,sym)
importFrom(scales,math_format)
importFrom(scales,trans_breaks)
importFrom(scales,trans_format)
importFrom(stringr,str_split)
importFrom(tibble,as_tibble)
importFrom(tibble,column_to_rownames)
importFrom(tibble,remove_rownames)
importFrom(tibble,rownames_to_column)
importFrom(tidyr,gather)
importFrom(tidyr,spread)
importFrom(tidyr,unite)
importMethodsFrom(BiocGenerics,plotMA)
