# DEGreport

<img src="https://raw.githubusercontent.com/lpantano/DEGreport/main/inst/sticker/degreport.png" width="150" height="150" align="right"/>


[![Build status](https://secure.travis-ci.org/lpantano/DEGreport.png)](https://travis-ci.org/lpantano/DEGreport)
[![Project Status: Active - The project has reached a stable, usable state and is being actively developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)
[![BioC Downloads](http://bioconductor.org//shields/downloads/DEGreport.svg)](http://bioconductor.org/packages/3.6/bioc/html/DEGreport.html)
[![coverage](https://img.shields.io/codecov/c/github/lpantano/DEGreport/master.svg)](https://codecov.io/github/lpantano/DEGreport?branch=master)
[![Support this project by running your production jobs at BatchX](https://images.batchx.io/gh-badge-logo.svg)](https://platform.batchx.io/lpantano-team/tools/degreport%2Fdeg-patterns "Support this project by running your production jobs at BatchX")

QCs, figures and analyses after differential expression with DESeq2 or other similar tool.

Pantano L (2017). DEGreport: Report of DEG analysis. R package version 1.13.8. 

DOI: [10.18129/B9.bioc.DEGreport](https://doi.org/doi:10.18129/B9.bioc.DEGreport)


## Installation

This is an [R][] package.

### [Bioconductor][] stable version

```r
if (!requireNamespace("BiocManager", quietly=TRUE))
    install.packages("BiocManager")
BiocManager::install("DEGreport")
```

### [Bioconductor][] latest version

```r
devtools::install_git("https://git@git.bioconductor.org/packages/DEGreport")
```

### [devtools][] unstable version

```r
install.packages("devtools")
devtools::install_github("lpantano/DEGreport")
```

Load the package and learn what to do:

`browseVignettes("DEGreport")`

Here is the last devel [vignette](https://bioconductor.org/packages/devel/bioc/vignettes/DEGreport/inst/doc/DEGreport.pdf).

[Bioconductor]: https://bioconductor.org
[bcbio-nextgen]: https://github.com/chapmanb/bcbio-nextgen
[devtools]: https://cran.r-project.org/package=devtools
[R]: https://www.r-project.org
