#' @name humanGender
#' @title DGEList object for DE genes betwen Male and Females
#' @description DGEList object for DE genes betwen Male and Females
#' @docType data
#' @usage data(humanGender)
#' @format DGEList
#' @source gEUvadis
#' @author Lorena Pantano, 2017-08-37
NULL