#' @name geneInfo
#' @title data.frame with chromose information for each gene
#' @description data.frame with chromose information for each gene
#' @docType data
#' @usage data(geneInfo)
#' @format data.frame
#' @source biomart
#' @author Lorena Pantano, 2014-08-14
NULL