% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geneInfo.R
\docType{data}
\name{geneInfo}
\alias{geneInfo}
\title{data.frame with chromose information for each gene}
\format{
data.frame
}
\source{
biomart
}
\usage{
data(geneInfo)
}
\description{
data.frame with chromose information for each gene
}
\author{
Lorena Pantano, 2014-08-14
}
